==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>تشغيل الواي فاي</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>إيقاف الواي فاي</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>أحرف كبيرة</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>أحرف صغيرة</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>تشغيل لوحة الأرقام</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>إيقاف لوحة الأرقام</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>تشغيل لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>إيقاف لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>تبديل لوحة اللمس</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>تبديل Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>تشغيل وضع الطيران</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>إيقاف وضع الطيران</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>طاقة متوازنة</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>وضع توفير الطاقة</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>وضع الأداء العالي</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>تم تفعيل تأثيرات النوافذ</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>تم تعطيل تأثيرات النوافذ</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>فشل في تفعيل تأثيرات النوافذ</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>إيقاف الميكروفون</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>تشغيل الميكروفون</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.2.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>تشغيل الواي فاي</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>إيقاف الواي فاي</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>أحرف كبيرة</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>أحرف صغيرة</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>تشغيل لوحة الأرقام</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>إيقاف لوحة الأرقام</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>تشغيل لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>إيقاف لوحة اللمس</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>تبديل لوحة اللمس</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>تبديل Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>تشغيل وضع الطيران</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>إيقاف وضع الطيران</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>طاقة متوازنة</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>وضع توفير الطاقة</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>وضع الأداء العالي</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>تم تفعيل تأثيرات النوافذ</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>تم تعطيل تأثيرات النوافذ</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>فشل في تفعيل تأثيرات النوافذ</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>إيقاف الميكروفون</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>تشغيل الميكروفون</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
